import everest

# create session by using client token
with open('.token') as f:
    token = f.read().strip()
session = everest.Session('Vina Screening', 'https://everest.distcomp.org', token=token)

# define Vina application
vina = everest.App('INSERT VINA APP ID', session)

try:
    # prepare tasks
    tasks = []
    for n in range(1,11):
        tasks.append({
            'receptor': open('inputs/screening/protein.pdbqt', 'rb'),
            'ligand': open('inputs/screening/ligand%d.pdbqt' % n, 'rb'),
            'center_x': 11,
            'center_y': 90.5,
            'center_z': 57.5,
            'size_x': 22,
            'size_y': 24,
            'size_z': 28,
            'exhaustiveness': 1
        })

    # submit all tasks
    jobs = vina.runAll(tasks)

    # process results
    results = []
    n = 1
    for job in jobs:
        try:
            result = job.result()
            session.getFile(result['output'], 'results/screening/ligand_out%d.pdbqt' % n)
            session.getFile(result['log'], 'results/screening/log%d.txt' % n)
            job.delete()
            with open('results/screening/ligand_out%d.pdbqt' % n) as out:
                lines = out.readlines()
                line = lines[1]
                result = float(line.split(':')[1].split()[0])
                results.append([result, n])
        except everest.JobException as e:
            print "Task %d error: %s" % (n, e)
        n += 1
    results.sort(lambda x,y: cmp(x[0], y[0]))
    for r in results:
        print "%f (task %d)" % (r[0], r[1])

finally:
    # always close the session on exit
    session.close()