import everest

# create session by using client token
with open('.token') as f:
    token = f.read().strip()
session = everest.Session('Vina Visualize', 'https://everest.distcomp.org', token=token)

# define applications
vina = everest.App('INSERT VINA APP ID', session)
pymol = everest.App('53ab27d0330000110d12a353', session)
png2gif = everest.App('53ab3efa32000041004b11c6', session)

# define resources
test = '53ad28ca35000042009832de'

try:
    # Step 1: perform docking with Vina
    job_vina = vina.run({
        'receptor': open('inputs/visualize/protein.pdbqt', 'rb'),
        'ligand': open('inputs/visualize/ligand.pdbqt', 'rb'),
        'center_x': 11,
        'center_y': 90.5,
        'center_z': 57.5,
        'size_x': 22,
        'size_y': 24,
        'size_z': 28,
        'exhaustiveness': 1
    })
    
    # Step 2: generate PNG images of docking results with PyMOL
    job_pymol = pymol.run({
        'script': open('inputs/visualize/script.pml', 'rb'),
        'files': [
            open('inputs/visualize/protein.pdb', 'rb'),
            job_vina.output('output')
        ]
    }, [test])

    # Step 3: convert PNG images to a single GIF file with ImageMagick
    job_png2gif = png2gif.run({
        'images': job_pymol.output('results'),
        'delay': 5
    }, [test])

    result = job_png2gif.result()
    session.getFile(result['gif'], 'results/visualize/movie.gif')

finally:
    # always close the session on exit
    session.close()